IngeoDash
==================================
.. image:: https://github.com/INGEOTEC/IngeoDash/actions/workflows/test.yaml/badge.svg
		:target: https://github.com/INGEOTEC/IngeoDash/actions/workflows/test.yaml

.. image:: https://coveralls.io/repos/github/INGEOTEC/IngeoDash/badge.svg?branch=develop
		:target: https://coveralls.io/github/INGEOTEC/IngeoDash?branch=develop

.. image:: https://badge.fury.io/py/IngeoDash.svg
		:target: https://badge.fury.io/py/IngeoDash

.. image:: https://colab.research.google.com/assets/colab-badge.svg
		:target: https://colab.research.google.com/github/INGEOTEC/IngeoDash/blob/master/docs/IngeoDash.ipynb 

.. code-block:: bash

    python -m IngeoDash
